@@ -107,9 +107,9 @@ func TestFetchBackupInfo(t *testing.T) {
 				client.VeleroV1(),
 				client.VeleroV1(),
 				restorer,
-				sharedInformers.Velero().V1().Backups(),
-				sharedInformers.Velero().V1().BackupStorageLocations(),
-				sharedInformers.Velero().V1().VolumeSnapshotLocations(),
+				sharedInformers.Velero().V1().Backups().Lister(),
+				sharedInformers.Velero().V1().BackupStorageLocations().Lister(),
+				sharedInformers.Velero().V1().VolumeSnapshotLocations().Lister(),
 				logger,
 				logrus.InfoLevel,
 				func(logrus.FieldLogger) clientmgmt.Manager { return pluginManager },
@@ -203,9 +203,9 @@ func TestProcessQueueItemSkips(t *testing.T) {
 				client.VeleroV1(),
 				client.VeleroV1(),
 				restorer,
-				sharedInformers.Velero().V1().Backups(),
-				sharedInformers.Velero().V1().BackupStorageLocations(),
-				sharedInformers.Velero().V1().VolumeSnapshotLocations(),
+				sharedInformers.Velero().V1().Backups().Lister(),
+				sharedInformers.Velero().V1().BackupStorageLocations().Lister(),
+				sharedInformers.Velero().V1().VolumeSnapshotLocations().Lister(),
 				logger,
 				logrus.InfoLevel,
 				nil,
@@ -408,9 +408,9 @@ func TestProcessQueueItem(t *testing.T) {
 				client.VeleroV1(),
 				client.VeleroV1(),
 				restorer,
-				sharedInformers.Velero().V1().Backups(),
-				sharedInformers.Velero().V1().BackupStorageLocations(),
-				sharedInformers.Velero().V1().VolumeSnapshotLocations(),
+				sharedInformers.Velero().V1().Backups().Lister(),
+				sharedInformers.Velero().V1().BackupStorageLocations().Lister(),
+				sharedInformers.Velero().V1().VolumeSnapshotLocations().Lister(),
 				logger,
 				logrus.InfoLevel,
 				func(logrus.FieldLogger) clientmgmt.Manager { return pluginManager },
@@ -633,9 +633,9 @@ func TestvalidateAndCompleteWhenScheduleNameSpecified(t *testing.T) {
 		client.VeleroV1(),
 		client.VeleroV1(),
 		nil,
-		sharedInformers.Velero().V1().Backups(),
-		sharedInformers.Velero().V1().BackupStorageLocations(),
-		sharedInformers.Velero().V1().VolumeSnapshotLocations(),
+		sharedInformers.Velero().V1().Backups().Lister(),
+		sharedInformers.Velero().V1().BackupStorageLocations().Lister(),
+		sharedInformers.Velero().V1().VolumeSnapshotLocations().Lister(),
 		logger,
 		logrus.DebugLevel,
 		nil,
